@@ -5,12 +5,12 @@ from common import *
 
 class general_dialog:
 	def destroy(self):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
-		self.xml.get_widget(self.name).destroy()
+		self.general_get_widget(self.name).destroy()
 
 	def on_generalField1_key_press_event(self, widget, event):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		if event.keyval == 65307: # Escape
 			self.generalValue = CANCEL;
@@ -18,27 +18,27 @@ class general_dialog:
 
 		if event.keyval == 65289: # tab
 			if self.generalNumFields > 1:
-				self.xml.get_widget("generalField2").grab_focus()
+				self.general_get_widget("generalField2").grab_focus()
 				return 1
 			
 		if event.keyval == 65421 or event.keyval == 65293: # KP_Enter / Return
 			if self.generalNumFields > 1:
 				#generalDialog = gtk_widget_get_toplevel(widget);
-				self.xml.get_widget("generalField2").grab_focus()
+				self.general_get_widget("generalField2").grab_focus()
 			else:
 				self.generalValue = OK;
 			return 1
 		return 0
 
 	def on_generalField2_key_press_event(self, widget, event):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		if event.keyval == 65307: # Escape
 			self.generalValue = CANCEL;
 			return 1
 
 		if event.keyval == 65289: # tab
-			self.xml.get_widget("generalField1").grab_focus()
+			self.general_get_widget("generalField1").grab_focus()
 			return 1
 			
 		if event.keyval == 65421 or event.keyval == 65293: # KP_Enter / Return
@@ -47,42 +47,42 @@ class general_dialog:
 		return 0
 
 	def on_generalOK_clicked(self, widget):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.generalValue = OK
 
 	def on_generalNo_clicked(self, widget):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.generalValue = NO
 
 	def on_generalCancel_clicked(self, widget):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.generalValue = CANCEL
 
 	def on_generalTryagain_clicked(self, widget):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.generalValue = TRYAGAIN
 
 	def on_generalReadonly_clicked(self, widget):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.generalValue = READONLY
 
 	def get_field1(self):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		return self.field1
 
 	def get_field2(self):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		return self.field2
 
 	def get_value(self):
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		return self.generalValue
 	
@@ -90,7 +90,7 @@ class general_dialog:
 				 field1_label = "", field1_default = "",
 				 field2_label = "", field2_default = ""):
 		self.gui = gui
-		if self.gui.trace:
+		if self.gui.debug:
 			print inspect.getframeinfo(inspect.currentframe())[2], vars()
 
 		callbacks = {
@@ -109,66 +109,73 @@ class general_dialog:
 		self.generalNumFields = num_fields
 		self.name = "generalDialog"
 
-		self.gui_filename = gui.gui_filename
-		self.xml = gtk.glade.XML(self.gui_filename, self.name, domain="gjots2")
-		self.xml.signal_autoconnect(callbacks)
-
-		#gtk.Widget.show(self)
-		self.xml.get_widget(self.name).set_transient_for(self.gui.gjots)
-		self.xml.get_widget(self.name).set_title(title)
-		self.xml.get_widget("generalPromptLabel").set_label(prompt)
-		if num_fields < 1:
-			self.xml.get_widget("generalLabel1").hide()
-			self.xml.get_widget("generalField1").hide()
+		self.filename = self.gui.sharedir + "ui/generalDialog.ui"
+		if self.gui.builder:
+			self.gui.builder.add_from_file(self.filename)
+			self.gui.builder.connect_signals(callbacks)
+			self.general_get_widget = self.gui.gui_get_widget
 		else:
-			self.xml.get_widget("generalLabel1").set_label(field1_label)
-			self.xml.get_widget("generalLabel1").show()
-			self.xml.get_widget("generalField1").set_text(field1_default)
-			self.xml.get_widget("generalField1").set_visibility(not secretp)
-			self.xml.get_widget("generalField1").show()
+			self.xml = gtk.glade.XML(self.gui.gui_filename, self.name, domain="gjots2")
+			self.xml.signal_autoconnect(callbacks)
+			self.general_get_widget = self.xml.get_widget
+
+		self.general_dialog = self.general_get_widget(self.name)
+		#gtk.Widget.show(self)
+		self.general_dialog.set_transient_for(self.gui.gjots)
+		self.general_dialog.set_title(title)
+		self.general_get_widget("generalPromptLabel").set_label(prompt)
+		if num_fields < 1:
+			self.general_get_widget("generalLabel1").hide()
+			self.general_get_widget("generalField1").hide()
+		else:
+			self.general_get_widget("generalLabel1").set_label(field1_label)
+			self.general_get_widget("generalLabel1").show()
+			self.general_get_widget("generalField1").set_text(field1_default)
+			self.general_get_widget("generalField1").set_visibility(not secretp)
+			self.general_get_widget("generalField1").show()
 			
 		if num_fields < 2:
-			self.xml.get_widget("generalLabel2").hide()
-			self.xml.get_widget("generalField2").hide()
+			self.general_get_widget("generalLabel2").hide()
+			self.general_get_widget("generalField2").hide()
 		else:
-			self.xml.get_widget("generalLabel2").set_label(field2_label)
-			self.xml.get_widget("generalLabel2").show()
-			self.xml.get_widget("generalField2").set_text(field2_default)
-			self.xml.get_widget("generalField2").set_visibility(not secretp)
-			self.xml.get_widget("generalField2").show()
+			self.general_get_widget("generalLabel2").set_label(field2_label)
+			self.general_get_widget("generalLabel2").show()
+			self.general_get_widget("generalField2").set_text(field2_default)
+			self.general_get_widget("generalField2").set_visibility(not secretp)
+			self.general_get_widget("generalField2").show()
 
 		if feedback:
-			self.xml.get_widget("generalFeedback").set_label(feedback)
-			self.xml.get_widget("generalFeedback").show()
+			self.general_get_widget("generalFeedback").set_label(feedback)
+			self.general_get_widget("generalFeedback").show()
 		else:
-			self.xml.get_widget("generalFeedback").hide()
+			self.general_get_widget("generalFeedback").hide()
 
 		if (buttons & YES or buttons & OK):
-			self.xml.get_widget("generalOK").show()
+			self.general_get_widget("generalOK").show()
 			if (buttons & YES):
-				self.xml.get_widget("generalOK").set_label(_("Yes"))
+				self.general_get_widget("generalOK").set_label(_("Yes"))
 		else:
-			self.xml.get_widget("generalOK").hide()
+			self.general_get_widget("generalOK").hide()
 			
 		if (buttons & NO):
-			self.xml.get_widget("generalNo").show()
+			self.general_get_widget("generalNo").show()
 		else:
-			self.xml.get_widget("generalNo").hide()
+			self.general_get_widget("generalNo").hide()
 
 		if (buttons & CANCEL):
-			self.xml.get_widget("generalCancel").show()
+			self.general_get_widget("generalCancel").show()
 		else:
-			self.xml.get_widget("generalCancel").hide()
+			self.general_get_widget("generalCancel").hide()
 			
 		if (buttons & READONLY):
-			self.xml.get_widget("generalReadonly").show()
+			self.general_get_widget("generalReadonly").show()
 		else:
-			self.xml.get_widget("generalReadonly").hide()
+			self.general_get_widget("generalReadonly").hide()
 			
 		if (buttons & TRYAGAIN):
-			self.xml.get_widget("generalTryagain").show()
+			self.general_get_widget("generalTryagain").show()
 		else:
-			self.xml.get_widget("generalTryagain").hide()
+			self.general_get_widget("generalTryagain").hide()
 			
 		self.generalValue = WAITING
 
@@ -177,11 +184,11 @@ class general_dialog:
 
 		if self.generalValue == OK:
 			if num_fields > 1:
-				self.field2 = self.xml.get_widget("generalField2").get_text()
+				self.field2 = self.general_get_widget("generalField2").get_text()
 			if num_fields > 0:
-				self.field1 = self.xml.get_widget("generalField1").get_text()
+				self.field1 = self.general_get_widget("generalField1").get_text()
 
-		self.xml.get_widget(self.name).destroy()
+		self.general_get_widget(self.name).destroy()
 
 # Local variables:
 # eval:(setq compile-command "cd ..; ./gjots2 test.gjots")
